/* libxml-Node.c generated by valac 0.28.1, the Vala compiler
 * generated from libxml-Node.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* xNode.vala
 *
 * Copyright (C) 2011-2013  Richard Schwarting <aquarichy@gmail.com>
 * Copyright (C) 2011-2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Richard Schwarting <aquarichy@gmail.com>
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_XNODE (gxml_xnode_get_type ())
#define GXML_XNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XNODE, GXmlxNode))
#define GXML_XNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_XNODE, GXmlxNodeClass))
#define GXML_IS_XNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XNODE))
#define GXML_IS_XNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_XNODE))
#define GXML_XNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_XNODE, GXmlxNodeClass))

typedef struct _GXmlxNode GXmlxNode;
typedef struct _GXmlxNodeClass GXmlxNodeClass;
typedef struct _GXmlxNodePrivate GXmlxNodePrivate;

#define GXML_TYPE_NAMESPACE_ATTR (gxml_namespace_attr_get_type ())
#define GXML_NAMESPACE_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE_ATTR, GXmlNamespaceAttr))
#define GXML_NAMESPACE_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_NAMESPACE_ATTR, GXmlNamespaceAttrClass))
#define GXML_IS_NAMESPACE_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE_ATTR))
#define GXML_IS_NAMESPACE_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_NAMESPACE_ATTR))
#define GXML_NAMESPACE_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_NAMESPACE_ATTR, GXmlNamespaceAttrClass))

typedef struct _GXmlNamespaceAttr GXmlNamespaceAttr;
typedef struct _GXmlNamespaceAttrClass GXmlNamespaceAttrClass;

#define GXML_TYPE_XNODE_LIST (gxml_xnode_list_get_type ())
#define GXML_XNODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XNODE_LIST, GXmlxNodeList))
#define GXML_IS_XNODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XNODE_LIST))
#define GXML_XNODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_XNODE_LIST, GXmlxNodeListIface))

typedef struct _GXmlxNodeList GXmlxNodeList;
typedef struct _GXmlxNodeListIface GXmlxNodeListIface;

#define GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP (gxml_abstract_named_attr_map_get_type ())
#define GXML_ABSTRACT_NAMED_ATTR_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP, GXmlAbstractNamedAttrMap))
#define GXML_ABSTRACT_NAMED_ATTR_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP, GXmlAbstractNamedAttrMapClass))
#define GXML_IS_ABSTRACT_NAMED_ATTR_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP))
#define GXML_IS_ABSTRACT_NAMED_ATTR_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP))
#define GXML_ABSTRACT_NAMED_ATTR_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ABSTRACT_NAMED_ATTR_MAP, GXmlAbstractNamedAttrMapClass))

typedef struct _GXmlAbstractNamedAttrMap GXmlAbstractNamedAttrMap;
typedef struct _GXmlAbstractNamedAttrMapClass GXmlAbstractNamedAttrMapClass;

#define GXML_TYPE_NAMED_ATTR_MAP (gxml_named_attr_map_get_type ())
#define GXML_NAMED_ATTR_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMED_ATTR_MAP, GXmlNamedAttrMap))
#define GXML_NAMED_ATTR_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_NAMED_ATTR_MAP, GXmlNamedAttrMapClass))
#define GXML_IS_NAMED_ATTR_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMED_ATTR_MAP))
#define GXML_IS_NAMED_ATTR_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_NAMED_ATTR_MAP))
#define GXML_NAMED_ATTR_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_NAMED_ATTR_MAP, GXmlNamedAttrMapClass))

typedef struct _GXmlNamedAttrMap GXmlNamedAttrMap;
typedef struct _GXmlNamedAttrMapClass GXmlNamedAttrMapClass;

#define GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST (gxml_abstract_namespace_attr_node_list_get_type ())
#define GXML_ABSTRACT_NAMESPACE_ATTR_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST, GXmlAbstractNamespaceAttrNodeList))
#define GXML_ABSTRACT_NAMESPACE_ATTR_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST, GXmlAbstractNamespaceAttrNodeListClass))
#define GXML_IS_ABSTRACT_NAMESPACE_ATTR_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST))
#define GXML_IS_ABSTRACT_NAMESPACE_ATTR_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST))
#define GXML_ABSTRACT_NAMESPACE_ATTR_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ABSTRACT_NAMESPACE_ATTR_NODE_LIST, GXmlAbstractNamespaceAttrNodeListClass))

typedef struct _GXmlAbstractNamespaceAttrNodeList GXmlAbstractNamespaceAttrNodeList;
typedef struct _GXmlAbstractNamespaceAttrNodeListClass GXmlAbstractNamespaceAttrNodeListClass;

#define GXML_TYPE_NAMESPACE_ATTR_NODE_LIST (gxml_namespace_attr_node_list_get_type ())
#define GXML_NAMESPACE_ATTR_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE_ATTR_NODE_LIST, GXmlNamespaceAttrNodeList))
#define GXML_NAMESPACE_ATTR_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_NAMESPACE_ATTR_NODE_LIST, GXmlNamespaceAttrNodeListClass))
#define GXML_IS_NAMESPACE_ATTR_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE_ATTR_NODE_LIST))
#define GXML_IS_NAMESPACE_ATTR_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_NAMESPACE_ATTR_NODE_LIST))
#define GXML_NAMESPACE_ATTR_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_NAMESPACE_ATTR_NODE_LIST, GXmlNamespaceAttrNodeListClass))

typedef struct _GXmlNamespaceAttrNodeList GXmlNamespaceAttrNodeList;
typedef struct _GXmlNamespaceAttrNodeListClass GXmlNamespaceAttrNodeListClass;

#define GXML_TYPE_XDOCUMENT (gxml_xdocument_get_type ())
#define GXML_XDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XDOCUMENT, GXmlxDocument))
#define GXML_XDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_XDOCUMENT, GXmlxDocumentClass))
#define GXML_IS_XDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XDOCUMENT))
#define GXML_IS_XDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_XDOCUMENT))
#define GXML_XDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_XDOCUMENT, GXmlxDocumentClass))

typedef struct _GXmlxDocument GXmlxDocument;
typedef struct _GXmlxDocumentClass GXmlxDocumentClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_DOM_EXCEPTION (gxml_dom_exception_get_type ())

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_X_UNKNOWN = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_childs) (GXmlNode* self);
	GeeBidirList* (*get_children) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlxNodeListIface {
	GTypeInterface parent_iface;
	GXmlxNode* (*item) (GXmlxNodeList* self, gulong idx);
	GXmlxNode* (*insert_before) (GXmlxNodeList* self, GXmlxNode* new_child, GXmlxNode* ref_child);
	GXmlxNode* (*replace_child) (GXmlxNodeList* self, GXmlxNode* new_child, GXmlxNode* old_child);
	GXmlxNode* (*remove_child) (GXmlxNodeList* self, GXmlxNode* old_child);
	GXmlxNode* (*append_child) (GXmlxNodeList* self, GXmlxNode* new_child);
	gchar* (*to_string) (GXmlxNodeList* self, gboolean in_line);
	GXmlxNode* (*first) (GXmlxNodeList* self);
	GXmlxNode* (*last) (GXmlxNodeList* self);
	GXmlxNode* (*get) (GXmlxNodeList* self, gint n);
	gulong (*get_length) (GXmlxNodeList* self);
	void (*set_length) (GXmlxNodeList* self, gulong value);
};

struct _GXmlxNode {
	GObject parent_instance;
	GXmlxNodePrivate * priv;
	GXmlxNodeList* _child_nodes;
	GXmlNamedAttrMap* _attributes;
	GXmlNamespaceAttrNodeList* _namespace_definitions;
};

struct _GXmlxNodeClass {
	GObjectClass parent_class;
	GXmlNamespaceAttr* (*add_namespace_attr) (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
	gboolean (*set_namespace) (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
	GXmlxNode* (*insert_before) (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* ref_child);
	GXmlxNode* (*replace_child) (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* old_child);
	GXmlxNode* (*remove_child) (GXmlxNode* self, GXmlxNode* old_child);
	GXmlxNode* (*append_child) (GXmlxNode* self, GXmlxNode* new_child);
	gboolean (*has_child_nodes) (GXmlxNode* self);
	GXmlxNode* (*clone_node) (GXmlxNode* self, gboolean deep);
	gchar* (*stringify) (GXmlxNode* self, gboolean format, gint level);
	gchar* (*to_string) (GXmlxNode* self);
	GeeList* (*get_namespace_definitions) (GXmlxNode* self);
	void (*set_namespace_definitions) (GXmlxNode* self, GeeList* value);
	const gchar* (*get_namespace_uri) (GXmlxNode* self);
	void (*set_namespace_uri) (GXmlxNode* self, const gchar* value);
	const gchar* (*get_namespace_prefix) (GXmlxNode* self);
	void (*set_namespace_prefix) (GXmlxNode* self, const gchar* value);
	const gchar* (*get_local_name) (GXmlxNode* self);
	void (*set_local_name) (GXmlxNode* self, const gchar* value);
	const gchar* (*get_node_name) (GXmlxNode* self);
	void (*set_node_name) (GXmlxNode* self, const gchar* value);
	const gchar* (*get_node_value) (GXmlxNode* self);
	void (*set_node_value) (GXmlxNode* self, const gchar* value);
	GXmlNodeType (*get_node_type) (GXmlxNode* self);
	void (*set_node_type) (GXmlxNode* self, GXmlNodeType value);
	GXmlxNode* (*get_parent_node) (GXmlxNode* self);
	void (*set_parent_node) (GXmlxNode* self, GXmlxNode* value);
	GXmlxNodeList* (*get_child_nodes) (GXmlxNode* self);
	void (*set_child_nodes) (GXmlxNode* self, GXmlxNodeList* value);
	GXmlxNode* (*get_first_child) (GXmlxNode* self);
	void (*set_first_child) (GXmlxNode* self, GXmlxNode* value);
	GXmlxNode* (*get_last_child) (GXmlxNode* self);
	void (*set_last_child) (GXmlxNode* self, GXmlxNode* value);
	GXmlxNode* (*get_previous_sibling) (GXmlxNode* self);
	void (*set_previous_sibling) (GXmlxNode* self, GXmlxNode* value);
	GXmlxNode* (*get_next_sibling) (GXmlxNode* self);
	void (*set_next_sibling) (GXmlxNode* self, GXmlxNode* value);
	GXmlNamedAttrMap* (*get_attributes) (GXmlxNode* self);
	void (*set_attributes) (GXmlxNode* self, GXmlNamedAttrMap* value);
	GeeList* (*get_namespaces) (GXmlxNode* self);
	GeeBidirList* (*get_children) (GXmlxNode* self);
	GeeMap* (*get_attrs) (GXmlxNode* self);
	gchar* (*get_name) (GXmlxNode* self);
	gchar* (*get_value) (GXmlxNode* self);
	void (*set_value) (GXmlxNode* self, const gchar* value);
	GXmlNode* (*get_parent) (GXmlxNode* self);
};

struct _GXmlxNodePrivate {
	gchar* _node_name;
	GXmlNodeType _node_type;
	GXmlxDocument* _owner_document;
};

typedef enum  {
	GXML_DOM_EXCEPTION_NONE,
	GXML_DOM_EXCEPTION_INDEX_SIZE,
	GXML_DOM_EXCEPTION_DOMSTRING_SIZE,
	GXML_DOM_EXCEPTION_HIERARCHY_REQUEST,
	GXML_DOM_EXCEPTION_WRONG_DOCUMENT,
	GXML_DOM_EXCEPTION_INVALID_CHARACTER,
	GXML_DOM_EXCEPTION_NO_DATA_ALLOWED,
	GXML_DOM_EXCEPTION_NO_MODIFICATION_ALLOWED,
	GXML_DOM_EXCEPTION_NOT_FOUND,
	GXML_DOM_EXCEPTION_NOT_SUPPORTED,
	GXML_DOM_EXCEPTION_INUSE_ATTRIBUTE,
	GXML_DOM_EXCEPTION_DOM,
	GXML_DOM_EXCEPTION_INVALID_DOC,
	GXML_DOM_EXCEPTION_INVALID_ROOT,
	GXML_DOM_EXCEPTION_NAMESPACE,
	GXML_DOM_EXCEPTION_X_OTHER
} GXmlDomException;


static gpointer gxml_xnode_parent_class = NULL;
static GXmlNodeIface* gxml_xnode_gxml_node_parent_iface = NULL;

GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_xnode_get_type (void) G_GNUC_CONST;
GType gxml_namespace_attr_get_type (void) G_GNUC_CONST;
GType gxml_xnode_list_get_type (void) G_GNUC_CONST;
GType gxml_abstract_named_attr_map_get_type (void) G_GNUC_CONST;
GType gxml_named_attr_map_get_type (void) G_GNUC_CONST;
GType gxml_abstract_namespace_attr_node_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_attr_node_list_get_type (void) G_GNUC_CONST;
GType gxml_xdocument_get_type (void) G_GNUC_CONST;
#define GXML_XNODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_XNODE, GXmlxNodePrivate))
enum  {
	GXML_XNODE_DUMMY_PROPERTY,
	GXML_XNODE_NAMESPACE_DEFINITIONS,
	GXML_XNODE_NAMESPACE_URI,
	GXML_XNODE_NAMESPACE_PREFIX,
	GXML_XNODE_LOCAL_NAME,
	GXML_XNODE_NODE_NAME,
	GXML_XNODE_NODE_VALUE,
	GXML_XNODE_NODE_TYPE,
	GXML_XNODE_PARENT_NODE,
	GXML_XNODE_CHILD_NODES,
	GXML_XNODE_FIRST_CHILD,
	GXML_XNODE_LAST_CHILD,
	GXML_XNODE_PREVIOUS_SIBLING,
	GXML_XNODE_NEXT_SIBLING,
	GXML_XNODE_ATTRIBUTES,
	GXML_XNODE_OWNER_DOCUMENT,
	GXML_XNODE_NAMESPACES,
	GXML_XNODE_CHILDREN,
	GXML_XNODE_ATTRS,
	GXML_XNODE_NAME,
	GXML_XNODE_VALUE,
	GXML_XNODE_TYPE_NODE,
	GXML_XNODE_DOCUMENT,
	GXML_XNODE_PARENT
};
GXmlxNode* gxml_xnode_construct (GType object_type, GXmlNodeType type, GXmlxDocument* owner);
void gxml_xnode_set_node_type (GXmlxNode* self, GXmlNodeType value);
void gxml_xnode_set_owner_document (GXmlxNode* self, GXmlxDocument* value);
GXmlxNode* gxml_xnode_construct_for_document (GType object_type);
void gxml_xnode_set_node_name (GXmlxNode* self, const gchar* value);
void gxml_xnode_check_wrong_document (GXmlxNode* self, GXmlxNode* node);
GXmlNodeType gxml_xnode_get_node_type (GXmlxNode* self);
GXmlxDocument* gxml_xnode_get_owner_document (GXmlxNode* self);
GType gxml_dom_exception_get_type (void) G_GNUC_CONST;
void gxml_warning (GXmlDomException ex, const gchar* message) G_GNUC_DEPRECATED;
gboolean gxml_xnode_check_read_only (GXmlxNode* self);
GXmlNamespaceAttr* gxml_xnode_add_namespace_attr (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
static GXmlNamespaceAttr* gxml_xnode_real_add_namespace_attr (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
gboolean gxml_xnode_set_namespace (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
static gboolean gxml_xnode_real_set_namespace (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix);
GXmlxNode* gxml_xnode_insert_before (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* ref_child);
static GXmlxNode* gxml_xnode_real_insert_before (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* ref_child);
GXmlxNode* gxml_xnode_replace_child (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* old_child);
static GXmlxNode* gxml_xnode_real_replace_child (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* old_child);
GXmlxNode* gxml_xnode_remove_child (GXmlxNode* self, GXmlxNode* old_child);
static GXmlxNode* gxml_xnode_real_remove_child (GXmlxNode* self, GXmlxNode* old_child);
GXmlxNode* gxml_xnode_append_child (GXmlxNode* self, GXmlxNode* new_child);
static GXmlxNode* gxml_xnode_real_append_child (GXmlxNode* self, GXmlxNode* new_child);
gboolean gxml_xnode_has_child_nodes (GXmlxNode* self);
static gboolean gxml_xnode_real_has_child_nodes (GXmlxNode* self);
GXmlxNode* gxml_xnode_clone_node (GXmlxNode* self, gboolean deep);
static GXmlxNode* gxml_xnode_real_clone_node (GXmlxNode* self, gboolean deep);
gchar* gxml_xnode_stringify (GXmlxNode* self, gboolean format, gint level);
static gchar* gxml_xnode_real_stringify (GXmlxNode* self, gboolean format, gint level);
const gchar* gxml_xnode_get_node_name (GXmlxNode* self);
gchar* gxml_xnode_to_string (GXmlxNode* self);
static gchar* gxml_xnode_real_to_string (GXmlxNode* self);
GeeList* gxml_xnode_get_namespace_definitions (GXmlxNode* self);
void gxml_xnode_set_namespace_definitions (GXmlxNode* self, GeeList* value);
const gchar* gxml_xnode_get_namespace_uri (GXmlxNode* self);
void gxml_xnode_set_namespace_uri (GXmlxNode* self, const gchar* value);
const gchar* gxml_xnode_get_namespace_prefix (GXmlxNode* self);
void gxml_xnode_set_namespace_prefix (GXmlxNode* self, const gchar* value);
const gchar* gxml_xnode_get_local_name (GXmlxNode* self);
void gxml_xnode_set_local_name (GXmlxNode* self, const gchar* value);
const gchar* gxml_xnode_get_node_value (GXmlxNode* self);
void gxml_xnode_set_node_value (GXmlxNode* self, const gchar* value);
GXmlxNode* gxml_xnode_get_parent_node (GXmlxNode* self);
void gxml_xnode_set_parent_node (GXmlxNode* self, GXmlxNode* value);
GXmlxNodeList* gxml_xnode_get_child_nodes (GXmlxNode* self);
void gxml_xnode_set_child_nodes (GXmlxNode* self, GXmlxNodeList* value);
GXmlxNode* gxml_xnode_get_first_child (GXmlxNode* self);
void gxml_xnode_set_first_child (GXmlxNode* self, GXmlxNode* value);
GXmlxNode* gxml_xnode_get_last_child (GXmlxNode* self);
void gxml_xnode_set_last_child (GXmlxNode* self, GXmlxNode* value);
GXmlxNode* gxml_xnode_get_previous_sibling (GXmlxNode* self);
void gxml_xnode_set_previous_sibling (GXmlxNode* self, GXmlxNode* value);
GXmlxNode* gxml_xnode_get_next_sibling (GXmlxNode* self);
void gxml_xnode_set_next_sibling (GXmlxNode* self, GXmlxNode* value);
GXmlNamedAttrMap* gxml_xnode_get_attributes (GXmlxNode* self);
void gxml_xnode_set_attributes (GXmlxNode* self, GXmlNamedAttrMap* value);
GeeList* gxml_xnode_get_namespaces (GXmlxNode* self);
GeeBidirList* gxml_xnode_get_children (GXmlxNode* self);
GeeMap* gxml_xnode_get_attrs (GXmlxNode* self);
gchar* gxml_xnode_get_name (GXmlxNode* self);
gchar* gxml_xnode_get_value (GXmlxNode* self);
void gxml_xnode_set_value (GXmlxNode* self, const gchar* value);
GXmlNode* gxml_xnode_get_parent (GXmlxNode* self);
static GObject * gxml_xnode_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void gxml_init_init (void);
static void gxml_xnode_finalize (GObject* obj);
GXmlNodeType gxml_node_get_type_node (GXmlNode* self);
GXmlDocument* gxml_node_get_document (GXmlNode* self);
static void _vala_gxml_xnode_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_xnode_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GXmlxNode* gxml_xnode_construct (GType object_type, GXmlNodeType type, GXmlxDocument* owner) {
	GXmlxNode * self = NULL;
	GXmlNodeType _tmp0_ = 0;
	GXmlxDocument* _tmp1_ = NULL;
	g_return_val_if_fail (owner != NULL, NULL);
	self = (GXmlxNode*) g_object_new (object_type, NULL);
	_tmp0_ = type;
	gxml_xnode_set_node_type (self, _tmp0_);
	_tmp1_ = owner;
	gxml_xnode_set_owner_document (self, _tmp1_);
	return self;
}


GXmlxNode* gxml_xnode_construct_for_document (GType object_type) {
	GXmlxNode * self = NULL;
	self = (GXmlxNode*) g_object_new (object_type, NULL);
	gxml_xnode_set_node_name (self, "#document");
	gxml_xnode_set_node_type (self, GXML_NODE_TYPE_DOCUMENT);
	return self;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


void gxml_xnode_check_wrong_document (GXmlxNode* self, GXmlxNode* node) {
	GXmlxDocument* this_doc = NULL;
	GXmlNodeType _tmp0_ = 0;
	GXmlNodeType _tmp1_ = 0;
	GXmlxDocument* _tmp5_ = NULL;
	GXmlxNode* _tmp6_ = NULL;
	GXmlxDocument* _tmp7_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (node != NULL);
	_tmp0_ = gxml_xnode_get_node_type (self);
	_tmp1_ = _tmp0_;
	if (_tmp1_ == GXML_NODE_TYPE_DOCUMENT) {
		GXmlxDocument* _tmp2_ = NULL;
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_XDOCUMENT, GXmlxDocument));
		_g_object_unref0 (this_doc);
		this_doc = _tmp2_;
	} else {
		GXmlxDocument* _tmp3_ = NULL;
		GXmlxDocument* _tmp4_ = NULL;
		_tmp3_ = self->priv->_owner_document;
		_tmp4_ = _g_object_ref0 (_tmp3_);
		_g_object_unref0 (this_doc);
		this_doc = _tmp4_;
	}
	_tmp5_ = this_doc;
	_tmp6_ = node;
	_tmp7_ = _tmp6_->priv->_owner_document;
	if (_tmp5_ != _tmp7_) {
		const gchar* _tmp8_ = NULL;
		_tmp8_ = _ ("Node tried to interact with a different document than the one it belon" \
"gs to");
		gxml_warning (GXML_DOM_EXCEPTION_WRONG_DOCUMENT, _tmp8_);
	}
	_g_object_unref0 (this_doc);
}


gboolean gxml_xnode_check_read_only (GXmlxNode* self) {
	gboolean result = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	result = FALSE;
	return result;
}


/**
 * Add a new namespace to this {@link GXml.xNode}
 */
static GXmlNamespaceAttr* gxml_xnode_real_add_namespace_attr (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix) {
	GXmlNamespaceAttr* result = NULL;
	g_return_val_if_fail (uri != NULL, NULL);
	result = NULL;
	return result;
}


GXmlNamespaceAttr* gxml_xnode_add_namespace_attr (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->add_namespace_attr (self, uri, namespace_prefix);
}


/**
 * Set namespace to this {@link GXml.xNode}
 *
 * Returns: true if namespace exists.
 */
static gboolean gxml_xnode_real_set_namespace (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix) {
	gboolean result = FALSE;
	g_return_val_if_fail (uri != NULL, FALSE);
	result = FALSE;
	return result;
}


gboolean gxml_xnode_set_namespace (GXmlxNode* self, const gchar* uri, const gchar* namespace_prefix) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_XNODE_GET_CLASS (self)->set_namespace (self, uri, namespace_prefix);
}


/**
 * Insert {@link new_child} as a child to this node, and place
 * it in the list before {@link ref_child}.
 *
 * If {@link ref_child} is %NULL, {@link new_child} is appended to the
 * list of children instead.
 *
 * Version: DOM Level 1 Core<<BR>>
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-insertBefore]]
 *
 * @param new_child A new {@link GXml.xNode} that will become a child of the current one
 * @param ref_child The child that {@link new_child} will be placed ahead of
 *
 * @return {@link new_child}, the node that has been
 * inserted.  Do not free it, its memory will be
 * released when the owning {@link GXml.xDocument} is
 * freed.
 */
static GXmlxNode* gxml_xnode_real_insert_before (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* ref_child) {
	GXmlxNode* result = NULL;
	g_return_val_if_fail (new_child != NULL, NULL);
	result = NULL;
	return result;
}


GXmlxNode* gxml_xnode_insert_before (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* ref_child) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->insert_before (self, new_child, ref_child);
}


/**
 * Replaces {@link old_child} with {@link new_child} in this node's list of children.
 *
 * Version: DOM Level 1 Core<<BR>>
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-replaceChild]]
 *
 * @param new_child A new {@link GXml.xNode} that will become a child of the current one
 * @param old_child A {@link GXml.xNode} that will be removed and replaced by {@link new_child}
 *
 * @return The removed node {@link old_child}.  Do not free it, its memory will be
 * released when the owning {@link GXml.xDocument} is
 * freed.
 */
static GXmlxNode* gxml_xnode_real_replace_child (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* old_child) {
	GXmlxNode* result = NULL;
	g_return_val_if_fail (new_child != NULL, NULL);
	g_return_val_if_fail (old_child != NULL, NULL);
	result = NULL;
	return result;
}


GXmlxNode* gxml_xnode_replace_child (GXmlxNode* self, GXmlxNode* new_child, GXmlxNode* old_child) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->replace_child (self, new_child, old_child);
}


/**
 * Removes {@link old_child} from this node's list of children,
 * {@link GXml.xNode.child_nodes}.
 *
 * Version: DOM Level 1 Core<<BR>>
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-removeChild]]
 *
 * @param old_child The {@link GXml.xNode} child to remove from the current one
 *
 * @return The removed node {@link old_child}.  Do not free it, its memory will be
 * released when the owning {@link GXml.xDocument} is
 * freed
 */
static GXmlxNode* gxml_xnode_real_remove_child (GXmlxNode* self, GXmlxNode* old_child) {
	GXmlxNode* result = NULL;
	g_return_val_if_fail (old_child != NULL, NULL);
	result = NULL;
	return result;
}


GXmlxNode* gxml_xnode_remove_child (GXmlxNode* self, GXmlxNode* old_child) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->remove_child (self, old_child);
}


/**
 * Appends {@link new_child} to the end of this node's list of children,
 * {@link GXml.xNode.child_nodes}.
 *
 * Version: DOM Level 1 Core<<BR>>
 *
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-appendChild]]
 *
 * @param new_child A new {@link GXml.xNode} that will
 * become the last child of this current node
 *
 * @return The newly added child, {@link new_child}.  Do not free it, its memory will be
 * released when the owning {@link GXml.xDocument} is
 * freed.
 */
static GXmlxNode* gxml_xnode_real_append_child (GXmlxNode* self, GXmlxNode* new_child) {
	GXmlxNode* result = NULL;
	g_return_val_if_fail (new_child != NULL, NULL);
	result = NULL;
	return result;
}


GXmlxNode* gxml_xnode_append_child (GXmlxNode* self, GXmlxNode* new_child) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->append_child (self, new_child);
}


/**
 * Indicates whether this node has children.
 *
 * Version: DOM Level 1 Core<<BR>>
 *
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-hasChildNodes]]
 *
 * @return true if this node has children, false if not
 */
static gboolean gxml_xnode_real_has_child_nodes (GXmlxNode* self) {
	gboolean result = FALSE;
	result = FALSE;
	return result;
}


gboolean gxml_xnode_has_child_nodes (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_XNODE_GET_CLASS (self)->has_child_nodes (self);
}


/**
 * Creates a parentless copy of this node.
 *
 * Version: DOM Level 1 Core<<BR>>
 *
 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#method-cloneNode]]
 *
 * @param deep If true, descendants are cloned as well. If false, they are not
 *
 * @return A parentless clone of this node.  Do not
 * free it, its memory will be released when the owning
 * {@link GXml.xDocument} is freed.
 */
static GXmlxNode* gxml_xnode_real_clone_node (GXmlxNode* self, gboolean deep) {
	GXmlxNode* result = NULL;
	result = NULL;
	return result;
}


GXmlxNode* gxml_xnode_clone_node (GXmlxNode* self, gboolean deep) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->clone_node (self, deep);
}


/**
 * Provides a string representation of this node.
 *
 * Note that if the DOM tree contains a Text node, a
 * CDATA section, or an EntityRef, it will not be
 * formatted, since the current implementation with
 * libxml2 will not handle that case.  (See libxml2's
 * xmlNodeDumpOutput internals to understand more.)
 *
 * @param format %FALSE: no formatting, true: formatted, with indentation
 * @param level Indentation level
 *
 * @return XML string for node, which must be free
 * this.
 */
static gchar* gxml_xnode_real_stringify (GXmlxNode* self, gboolean format, gint level) {
	gchar* result = NULL;
	GXmlNodeType _tmp0_ = 0;
	GXmlNodeType _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	_tmp0_ = gxml_xnode_get_node_type (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = gxml_xnode_get_node_name (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup_printf ("xNode(%d:%s)", (gint) _tmp1_, _tmp3_);
	result = _tmp4_;
	return result;
}


gchar* gxml_xnode_stringify (GXmlxNode* self, gboolean format, gint level) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->stringify (self, format, level);
}


static gchar* gxml_xnode_real_to_string (GXmlxNode* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	_tmp0_ = gxml_xnode_stringify (self, FALSE, 0);
	result = _tmp0_;
	return result;
}


gchar* gxml_xnode_to_string (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->to_string (self);
}


GeeList* gxml_xnode_get_namespace_definitions (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_namespace_definitions (self);
}


static GeeList* gxml_xnode_real_get_namespace_definitions (GXmlxNode* base) {
	GeeList* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_namespace_definitions (GXmlxNode* self, GeeList* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_namespace_definitions (self, value);
}


static void gxml_xnode_real_set_namespace_definitions (GXmlxNode* base, GeeList* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "namespace-definitions");
}


const gchar* gxml_xnode_get_namespace_uri (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_namespace_uri (self);
}


static const gchar* gxml_xnode_real_get_namespace_uri (GXmlxNode* base) {
	const gchar* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_namespace_uri (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_namespace_uri (self, value);
}


static void gxml_xnode_real_set_namespace_uri (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "namespace-uri");
}


const gchar* gxml_xnode_get_namespace_prefix (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_namespace_prefix (self);
}


static const gchar* gxml_xnode_real_get_namespace_prefix (GXmlxNode* base) {
	const gchar* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_namespace_prefix (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_namespace_prefix (self, value);
}


static void gxml_xnode_real_set_namespace_prefix (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "namespace-prefix");
}


const gchar* gxml_xnode_get_local_name (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_local_name (self);
}


static const gchar* gxml_xnode_real_get_local_name (GXmlxNode* base) {
	const gchar* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_local_name (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_local_name (self, value);
}


static void gxml_xnode_real_set_local_name (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "local-name");
}


const gchar* gxml_xnode_get_node_name (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_node_name (self);
}


static const gchar* gxml_xnode_real_get_node_name (GXmlxNode* base) {
	const gchar* result;
	GXmlxNode* self;
	const gchar* _tmp0_ = NULL;
	self = base;
	_tmp0_ = self->priv->_node_name;
	result = _tmp0_;
	return result;
}


void gxml_xnode_set_node_name (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_node_name (self, value);
}


static void gxml_xnode_real_set_node_name (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = base;
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_node_name);
	self->priv->_node_name = _tmp1_;
	g_object_notify ((GObject *) self, "node-name");
}


const gchar* gxml_xnode_get_node_value (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_node_value (self);
}


static const gchar* gxml_xnode_real_get_node_value (GXmlxNode* base) {
	const gchar* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_node_value (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_node_value (self, value);
}


static void gxml_xnode_real_set_node_value (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "node-value");
}


GXmlNodeType gxml_xnode_get_node_type (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_XNODE_GET_CLASS (self)->get_node_type (self);
}


static GXmlNodeType gxml_xnode_real_get_node_type (GXmlxNode* base) {
	GXmlNodeType result;
	GXmlxNode* self;
	GXmlNodeType _tmp0_ = 0;
	self = base;
	_tmp0_ = self->priv->_node_type;
	result = _tmp0_;
	return result;
}


void gxml_xnode_set_node_type (GXmlxNode* self, GXmlNodeType value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_node_type (self, value);
}


static void gxml_xnode_real_set_node_type (GXmlxNode* base, GXmlNodeType value) {
	GXmlxNode* self;
	GXmlNodeType _tmp0_ = 0;
	self = base;
	_tmp0_ = value;
	self->priv->_node_type = _tmp0_;
	g_object_notify ((GObject *) self, "node-type");
}


GXmlxNode* gxml_xnode_get_parent_node (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_parent_node (self);
}


static GXmlxNode* gxml_xnode_real_get_parent_node (GXmlxNode* base) {
	GXmlxNode* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_parent_node (GXmlxNode* self, GXmlxNode* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_parent_node (self, value);
}


static void gxml_xnode_real_set_parent_node (GXmlxNode* base, GXmlxNode* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "parent-node");
}


GXmlxNodeList* gxml_xnode_get_child_nodes (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_child_nodes (self);
}


static GXmlxNodeList* gxml_xnode_real_get_child_nodes (GXmlxNode* base) {
	GXmlxNodeList* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_child_nodes (GXmlxNode* self, GXmlxNodeList* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_child_nodes (self, value);
}


static void gxml_xnode_real_set_child_nodes (GXmlxNode* base, GXmlxNodeList* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "child-nodes");
}


GXmlxNode* gxml_xnode_get_first_child (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_first_child (self);
}


static GXmlxNode* gxml_xnode_real_get_first_child (GXmlxNode* base) {
	GXmlxNode* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_first_child (GXmlxNode* self, GXmlxNode* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_first_child (self, value);
}


static void gxml_xnode_real_set_first_child (GXmlxNode* base, GXmlxNode* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "first-child");
}


GXmlxNode* gxml_xnode_get_last_child (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_last_child (self);
}


static GXmlxNode* gxml_xnode_real_get_last_child (GXmlxNode* base) {
	GXmlxNode* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_last_child (GXmlxNode* self, GXmlxNode* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_last_child (self, value);
}


static void gxml_xnode_real_set_last_child (GXmlxNode* base, GXmlxNode* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "last-child");
}


GXmlxNode* gxml_xnode_get_previous_sibling (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_previous_sibling (self);
}


static GXmlxNode* gxml_xnode_real_get_previous_sibling (GXmlxNode* base) {
	GXmlxNode* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_previous_sibling (GXmlxNode* self, GXmlxNode* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_previous_sibling (self, value);
}


static void gxml_xnode_real_set_previous_sibling (GXmlxNode* base, GXmlxNode* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "previous-sibling");
}


GXmlxNode* gxml_xnode_get_next_sibling (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_next_sibling (self);
}


static GXmlxNode* gxml_xnode_real_get_next_sibling (GXmlxNode* base) {
	GXmlxNode* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_next_sibling (GXmlxNode* self, GXmlxNode* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_next_sibling (self, value);
}


static void gxml_xnode_real_set_next_sibling (GXmlxNode* base, GXmlxNode* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "next-sibling");
}


GXmlNamedAttrMap* gxml_xnode_get_attributes (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_attributes (self);
}


static GXmlNamedAttrMap* gxml_xnode_real_get_attributes (GXmlxNode* base) {
	GXmlNamedAttrMap* result;
	GXmlxNode* self;
	self = base;
	result = NULL;
	return result;
}


void gxml_xnode_set_attributes (GXmlxNode* self, GXmlNamedAttrMap* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_attributes (self, value);
}


static void gxml_xnode_real_set_attributes (GXmlxNode* base, GXmlNamedAttrMap* value) {
	GXmlxNode* self;
	self = base;
	g_object_notify ((GObject *) self, "attributes");
}


GXmlxDocument* gxml_xnode_get_owner_document (GXmlxNode* self) {
	GXmlxDocument* result;
	GXmlxDocument* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_owner_document;
	result = _tmp0_;
	return result;
}


void gxml_xnode_set_owner_document (GXmlxNode* self, GXmlxDocument* value) {
	GXmlxDocument* _tmp0_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_owner_document = _tmp0_;
	g_object_notify ((GObject *) self, "owner-document");
}


GeeList* gxml_xnode_get_namespaces (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_namespaces (self);
}


static GeeList* gxml_xnode_real_get_namespaces (GXmlxNode* base) {
	GeeList* result;
	GXmlxNode* self;
	GeeList* _tmp0_ = NULL;
	GeeList* _tmp1_ = NULL;
	GObject* _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_namespace_definitions (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_object_ref ((GObject*) _tmp1_);
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_LIST, GeeList));
	result = _tmp3_;
	return result;
}


GeeBidirList* gxml_xnode_get_children (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_children (self);
}


static GeeBidirList* gxml_xnode_real_get_children (GXmlxNode* base) {
	GeeBidirList* result;
	GXmlxNode* self;
	GXmlxNodeList* _tmp0_ = NULL;
	GXmlxNodeList* _tmp1_ = NULL;
	GObject* _tmp2_ = NULL;
	GeeBidirList* _tmp3_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_child_nodes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_object_ref ((GObject*) _tmp1_);
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_BIDIR_LIST, GeeBidirList));
	result = _tmp3_;
	return result;
}


GeeMap* gxml_xnode_get_attrs (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_attrs (self);
}


static GeeMap* gxml_xnode_real_get_attrs (GXmlxNode* base) {
	GeeMap* result;
	GXmlxNode* self;
	GXmlNamedAttrMap* _tmp0_ = NULL;
	GXmlNamedAttrMap* _tmp1_ = NULL;
	GObject* _tmp2_ = NULL;
	GeeMap* _tmp3_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_attributes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_object_ref ((GObject*) _tmp1_);
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_MAP, GeeMap));
	result = _tmp3_;
	return result;
}


gchar* gxml_xnode_get_name (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_name (self);
}


static gchar* gxml_xnode_real_get_name (GXmlxNode* base) {
	gchar* result;
	GXmlxNode* self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_node_name (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}


gchar* gxml_xnode_get_value (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_value (self);
}


static gchar* gxml_xnode_real_get_value (GXmlxNode* base) {
	gchar* result;
	GXmlxNode* self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_node_value (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}


void gxml_xnode_set_value (GXmlxNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_XNODE_GET_CLASS (self)->set_value (self, value);
}


static void gxml_xnode_real_set_value (GXmlxNode* base, const gchar* value) {
	GXmlxNode* self;
	const gchar* _tmp0_ = NULL;
	self = base;
	_tmp0_ = value;
	gxml_xnode_set_node_value (self, _tmp0_);
	g_object_notify ((GObject *) self, "value");
}


static GXmlNodeType gxml_xnode_real_get_type_node (GXmlNode* base) {
	GXmlNodeType result;
	GXmlxNode* self;
	GXmlNodeType _tmp0_ = 0;
	GXmlNodeType _tmp1_ = 0;
	self = (GXmlxNode*) base;
	_tmp0_ = gxml_xnode_get_node_type (self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static GXmlDocument* gxml_xnode_real_get_document (GXmlNode* base) {
	GXmlDocument* result;
	GXmlxNode* self;
	GXmlxDocument* _tmp0_ = NULL;
	self = (GXmlxNode*) base;
	_tmp0_ = self->priv->_owner_document;
	result = (GXmlDocument*) _tmp0_;
	return result;
}


GXmlNode* gxml_xnode_get_parent (GXmlxNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_XNODE_GET_CLASS (self)->get_parent (self);
}


static GXmlNode* gxml_xnode_real_get_parent (GXmlxNode* base) {
	GXmlNode* result;
	GXmlxNode* self;
	GXmlxNode* _tmp0_ = NULL;
	GXmlxNode* _tmp1_ = NULL;
	GXmlxNode* _tmp2_ = NULL;
	GXmlxNode* _tmp3_ = NULL;
	GObject* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	self = base;
	_tmp0_ = gxml_xnode_get_parent_node (self);
	_tmp1_ = _tmp0_;
	if (_tmp1_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp2_ = gxml_xnode_get_parent_node (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_object_ref ((GObject*) _tmp3_);
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp4_) : NULL);
	result = _tmp5_;
	return result;
}


static GObject * gxml_xnode_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlxNode * self;
	parent_class = G_OBJECT_CLASS (gxml_xnode_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_XNODE, GXmlxNode);
	gxml_init_init ();
	return obj;
}


static void gxml_xnode_class_init (GXmlxNodeClass * klass) {
	gxml_xnode_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlxNodePrivate));
	((GXmlxNodeClass *) klass)->add_namespace_attr = gxml_xnode_real_add_namespace_attr;
	((GXmlxNodeClass *) klass)->set_namespace = gxml_xnode_real_set_namespace;
	((GXmlxNodeClass *) klass)->insert_before = gxml_xnode_real_insert_before;
	((GXmlxNodeClass *) klass)->replace_child = gxml_xnode_real_replace_child;
	((GXmlxNodeClass *) klass)->remove_child = gxml_xnode_real_remove_child;
	((GXmlxNodeClass *) klass)->append_child = gxml_xnode_real_append_child;
	((GXmlxNodeClass *) klass)->has_child_nodes = gxml_xnode_real_has_child_nodes;
	((GXmlxNodeClass *) klass)->clone_node = gxml_xnode_real_clone_node;
	((GXmlxNodeClass *) klass)->stringify = gxml_xnode_real_stringify;
	((GXmlxNodeClass *) klass)->to_string = gxml_xnode_real_to_string;
	GXML_XNODE_CLASS (klass)->get_namespace_definitions = gxml_xnode_real_get_namespace_definitions;
	GXML_XNODE_CLASS (klass)->set_namespace_definitions = gxml_xnode_real_set_namespace_definitions;
	GXML_XNODE_CLASS (klass)->get_namespace_uri = gxml_xnode_real_get_namespace_uri;
	GXML_XNODE_CLASS (klass)->set_namespace_uri = gxml_xnode_real_set_namespace_uri;
	GXML_XNODE_CLASS (klass)->get_namespace_prefix = gxml_xnode_real_get_namespace_prefix;
	GXML_XNODE_CLASS (klass)->set_namespace_prefix = gxml_xnode_real_set_namespace_prefix;
	GXML_XNODE_CLASS (klass)->get_local_name = gxml_xnode_real_get_local_name;
	GXML_XNODE_CLASS (klass)->set_local_name = gxml_xnode_real_set_local_name;
	GXML_XNODE_CLASS (klass)->get_node_name = gxml_xnode_real_get_node_name;
	GXML_XNODE_CLASS (klass)->set_node_name = gxml_xnode_real_set_node_name;
	GXML_XNODE_CLASS (klass)->get_node_value = gxml_xnode_real_get_node_value;
	GXML_XNODE_CLASS (klass)->set_node_value = gxml_xnode_real_set_node_value;
	GXML_XNODE_CLASS (klass)->get_node_type = gxml_xnode_real_get_node_type;
	GXML_XNODE_CLASS (klass)->set_node_type = gxml_xnode_real_set_node_type;
	GXML_XNODE_CLASS (klass)->get_parent_node = gxml_xnode_real_get_parent_node;
	GXML_XNODE_CLASS (klass)->set_parent_node = gxml_xnode_real_set_parent_node;
	GXML_XNODE_CLASS (klass)->get_child_nodes = gxml_xnode_real_get_child_nodes;
	GXML_XNODE_CLASS (klass)->set_child_nodes = gxml_xnode_real_set_child_nodes;
	GXML_XNODE_CLASS (klass)->get_first_child = gxml_xnode_real_get_first_child;
	GXML_XNODE_CLASS (klass)->set_first_child = gxml_xnode_real_set_first_child;
	GXML_XNODE_CLASS (klass)->get_last_child = gxml_xnode_real_get_last_child;
	GXML_XNODE_CLASS (klass)->set_last_child = gxml_xnode_real_set_last_child;
	GXML_XNODE_CLASS (klass)->get_previous_sibling = gxml_xnode_real_get_previous_sibling;
	GXML_XNODE_CLASS (klass)->set_previous_sibling = gxml_xnode_real_set_previous_sibling;
	GXML_XNODE_CLASS (klass)->get_next_sibling = gxml_xnode_real_get_next_sibling;
	GXML_XNODE_CLASS (klass)->set_next_sibling = gxml_xnode_real_set_next_sibling;
	GXML_XNODE_CLASS (klass)->get_attributes = gxml_xnode_real_get_attributes;
	GXML_XNODE_CLASS (klass)->set_attributes = gxml_xnode_real_set_attributes;
	GXML_XNODE_CLASS (klass)->get_namespaces = gxml_xnode_real_get_namespaces;
	GXML_XNODE_CLASS (klass)->get_children = gxml_xnode_real_get_children;
	GXML_XNODE_CLASS (klass)->get_attrs = gxml_xnode_real_get_attrs;
	GXML_XNODE_CLASS (klass)->get_name = gxml_xnode_real_get_name;
	GXML_XNODE_CLASS (klass)->get_value = gxml_xnode_real_get_value;
	GXML_XNODE_CLASS (klass)->set_value = gxml_xnode_real_set_value;
	GXML_XNODE_CLASS (klass)->get_parent = gxml_xnode_real_get_parent;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_xnode_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_xnode_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_xnode_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_xnode_finalize;
	/**
	 * The list of attributes that store namespace definitions.  This is not part of a DOM spec.
	 *
	 * The caller must free this using {@link GLib.Object.unref}.
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NAMESPACE_DEFINITIONS, g_param_spec_object ("namespace-definitions", "namespace-definitions", "namespace-definitions", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the URI describing the node's namespace.
	 * This only applies to Elements and Attrs from DOM
	 * Level 2 Core that were created with namespace
	 * support.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 2 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-NodeNSname]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NAMESPACE_URI, g_param_spec_string ("namespace-uri", "namespace-uri", "namespace-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the namespace prefix for the node. This
	 * only applies to Elements and Attrs from DOM Level 2
	 * Core that were created with namespace support.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 2 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-NodeNSPrefix]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NAMESPACE_PREFIX, g_param_spec_string ("namespace-prefix", "namespace-prefix", "namespace-prefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the local name within the namespace. This
	 * only applies to Elements and Attrs from DOM Level 2
	 * Core that were created with namespace support.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 2 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-NodeNSLocalN]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_LOCAL_NAME, g_param_spec_string ("local-name", "local-name", "local-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the name of the node. Sometimes this is
	 * similar to the node type, but sometimes, it is
	 * arbitrary data, like for {@link GXml.Attribute} where
	 * the node_name is the name of the Attr's name=value
	 * pair.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-F68D095]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NODE_NAME, g_param_spec_string ("node-name", "node-name", "node-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the value of the xNode. The nature of
	 * node_value varies based on the type of node. This
	 * can be %NULL.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-F68D080]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NODE_VALUE, g_param_spec_string ("node-value", "node-value", "node-value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Stores the type of node. Most XML structures are
	 * nodes of different types, like {@link GXml.xDocument}
	 * as a {@link GXml.NodeType.DOCUMENT}, {@link GXml.Attribute}
	 * as a {@link GXml.NodeType.ATTRIBUTE}, Element as a
	 * {@link GXml.NodeType.ELEMENT}, etc.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-111237558]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NODE_TYPE, g_param_spec_enum ("node-type", "node-type", "node-type", GXML_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * A link to the parent_node of this node. For example,
	 * with elements, the immediate, outer element is the parent.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1060184317]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", GXML_TYPE_XNODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * List of child nodes to this node. These sometimes
	 * represent the value of a node as a tree of
	 * {@link GXml.xNode}, whereas node_value represents
	 * it as a string. This can be %NULL for node types
	 * that have no children.
	 *
	 * The {@link GXml.NodeList} is live, in that changes to this
	 * node's children will be reflected in an
	 * already-active {@link GXml.NodeList}.
	 *
	 * The caller must call {@link GLib.Object.unref} on
	 * the list when it is done with it.  The lists are
	 * constructed dynamically.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1451460987]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_CHILD_NODES, g_param_spec_object ("child-nodes", "child-nodes", "child-nodes", GXML_TYPE_XNODE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Links to the first child. If there are no
	 * children, it returns %NULL.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-169727388]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_FIRST_CHILD, g_param_spec_object ("first-child", "first-child", "first-child", GXML_TYPE_XNODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Links to the last child. If there are no
	 * children, it returns %NULL.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-61AD09FB]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_LAST_CHILD, g_param_spec_object ("last-child", "last-child", "last-child", GXML_TYPE_XNODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Links to this node's preceding sibling. If there
	 * are no previous siblings, it returns %NULL. Note
	 * that the children of a node are ordered.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-640FB3C8]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_PREVIOUS_SIBLING, g_param_spec_object ("previous-sibling", "previous-sibling", "previous-sibling", GXML_TYPE_XNODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * Links to this node's next sibling. If there is no
	 * next sibling, it returns %NULL. Note that the
	 * children of a node are ordered.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-6AC54C2F]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NEXT_SIBLING, g_param_spec_object ("next-sibling", "next-sibling", "next-sibling", GXML_TYPE_XNODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * A {@link GXml.NamedNodeMap} containing the {@link GXml.Attribute}
	 * attributes for this node. `attributes`
	 * actually only apply to {@link GXml.Element}
	 * nodes. For all other {@link GXml.xNode} subclasses,
	 * `attributes` is %NULL.
	 *
	 * Do not free this.  It's memory will be released
	 * when the owning {@link GXml.xDocument} is freed.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-84CF09]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_ATTRIBUTES, g_param_spec_object ("attributes", "attributes", "attributes", GXML_TYPE_NAMED_ATTR_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	 * A link to the {@link GXml.xDocument} to which this node belongs.
	 *
	 * Do not free this unless you intend to free all
	 * memory owned by the {@link GXml.xDocument}, including this
	 * {@link GXml.xNode}.
	 *
	 * Version: DOM Level 1 Core<<BR>>
	 * URL: [[http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#node-ownerDoc]]
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_OWNER_DOCUMENT, g_param_spec_object ("owner-document", "owner-document", "owner-document", GXML_TYPE_XDOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NAMESPACES, g_param_spec_object ("namespaces", "namespaces", "namespaces", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_CHILDREN, g_param_spec_object ("children", "children", "children", GEE_TYPE_BIDIR_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_ATTRS, g_param_spec_object ("attrs", "attrs", "attrs", GEE_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_TYPE_NODE, g_param_spec_enum ("type-node", "type-node", "type-node", GXML_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_DOCUMENT, g_param_spec_object ("document", "document", "document", GXML_TYPE_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_XNODE_PARENT, g_param_spec_object ("parent", "parent", "parent", GXML_TYPE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_xnode_gxml_node_interface_init (GXmlNodeIface * iface) {
	gxml_xnode_gxml_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->set_namespace = (gboolean (*)(GXmlNode*, const gchar*, const gchar*)) gxml_xnode_set_namespace;
	iface->to_string = (gchar* (*)(GXmlNode*)) gxml_xnode_to_string;
	iface->get_namespaces = (GeeList* (*) (GXmlNode *)) gxml_xnode_get_namespaces;
	iface->get_children = (GeeBidirList* (*) (GXmlNode *)) gxml_xnode_get_children;
	iface->get_attrs = (GeeMap* (*) (GXmlNode *)) gxml_xnode_get_attrs;
	iface->get_name = (gchar* (*) (GXmlNode *)) gxml_xnode_get_name;
	iface->get_value = (gchar* (*) (GXmlNode *)) gxml_xnode_get_value;
	iface->set_value = (void (*) (GXmlNode *, const gchar*)) gxml_xnode_set_value;
	iface->get_type_node = gxml_xnode_real_get_type_node;
	iface->get_document = gxml_xnode_real_get_document;
	iface->get_parent = (GXmlNode* (*) (GXmlNode *)) gxml_xnode_get_parent;
}


static void gxml_xnode_instance_init (GXmlxNode * self) {
	self->priv = GXML_XNODE_GET_PRIVATE (self);
	self->_attributes = NULL;
	self->_namespace_definitions = NULL;
}


static void gxml_xnode_finalize (GObject* obj) {
	GXmlxNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_XNODE, GXmlxNode);
	_g_object_unref0 (self->_child_nodes);
	_g_object_unref0 (self->_attributes);
	_g_object_unref0 (self->_namespace_definitions);
	_g_free0 (self->priv->_node_name);
	G_OBJECT_CLASS (gxml_xnode_parent_class)->finalize (obj);
}


/**
 * Represents an XML xNode, the base class for most XML structures in
 * the {@link GXml.xDocument}'s tree.
 * 
 * {@link GXml.xDocument}s are {@link GXml.xNode}s, and are
 * composed of a tree of {@link GXml.xNode}s.
 * 
 * Version: DOM Level 1 Core<<BR>>
 * URL: [[http://www.w3.org/TR/DOM-Level-1/level-one-core.html#ID-1950641247]]
 */
GType gxml_xnode_get_type (void) {
	static volatile gsize gxml_xnode_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_xnode_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlxNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_xnode_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlxNode), 0, (GInstanceInitFunc) gxml_xnode_instance_init, NULL };
		static const GInterfaceInfo gxml_node_info = { (GInterfaceInitFunc) gxml_xnode_gxml_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_xnode_type_id;
		gxml_xnode_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlxNode", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (gxml_xnode_type_id, GXML_TYPE_NODE, &gxml_node_info);
		g_once_init_leave (&gxml_xnode_type_id__volatile, gxml_xnode_type_id);
	}
	return gxml_xnode_type_id__volatile;
}


static void _vala_gxml_xnode_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlxNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_XNODE, GXmlxNode);
	switch (property_id) {
		case GXML_XNODE_NAMESPACE_DEFINITIONS:
		g_value_set_object (value, gxml_xnode_get_namespace_definitions (self));
		break;
		case GXML_XNODE_NAMESPACE_URI:
		g_value_set_string (value, gxml_xnode_get_namespace_uri (self));
		break;
		case GXML_XNODE_NAMESPACE_PREFIX:
		g_value_set_string (value, gxml_xnode_get_namespace_prefix (self));
		break;
		case GXML_XNODE_LOCAL_NAME:
		g_value_set_string (value, gxml_xnode_get_local_name (self));
		break;
		case GXML_XNODE_NODE_NAME:
		g_value_set_string (value, gxml_xnode_get_node_name (self));
		break;
		case GXML_XNODE_NODE_VALUE:
		g_value_set_string (value, gxml_xnode_get_node_value (self));
		break;
		case GXML_XNODE_NODE_TYPE:
		g_value_set_enum (value, gxml_xnode_get_node_type (self));
		break;
		case GXML_XNODE_PARENT_NODE:
		g_value_set_object (value, gxml_xnode_get_parent_node (self));
		break;
		case GXML_XNODE_CHILD_NODES:
		g_value_set_object (value, gxml_xnode_get_child_nodes (self));
		break;
		case GXML_XNODE_FIRST_CHILD:
		g_value_set_object (value, gxml_xnode_get_first_child (self));
		break;
		case GXML_XNODE_LAST_CHILD:
		g_value_set_object (value, gxml_xnode_get_last_child (self));
		break;
		case GXML_XNODE_PREVIOUS_SIBLING:
		g_value_set_object (value, gxml_xnode_get_previous_sibling (self));
		break;
		case GXML_XNODE_NEXT_SIBLING:
		g_value_set_object (value, gxml_xnode_get_next_sibling (self));
		break;
		case GXML_XNODE_ATTRIBUTES:
		g_value_set_object (value, gxml_xnode_get_attributes (self));
		break;
		case GXML_XNODE_OWNER_DOCUMENT:
		g_value_set_object (value, gxml_xnode_get_owner_document (self));
		break;
		case GXML_XNODE_NAMESPACES:
		g_value_take_object (value, gxml_xnode_get_namespaces (self));
		break;
		case GXML_XNODE_CHILDREN:
		g_value_take_object (value, gxml_xnode_get_children (self));
		break;
		case GXML_XNODE_ATTRS:
		g_value_take_object (value, gxml_xnode_get_attrs (self));
		break;
		case GXML_XNODE_NAME:
		g_value_take_string (value, gxml_xnode_get_name (self));
		break;
		case GXML_XNODE_VALUE:
		g_value_take_string (value, gxml_xnode_get_value (self));
		break;
		case GXML_XNODE_TYPE_NODE:
		g_value_set_enum (value, gxml_node_get_type_node ((GXmlNode*) self));
		break;
		case GXML_XNODE_DOCUMENT:
		g_value_set_object (value, gxml_node_get_document ((GXmlNode*) self));
		break;
		case GXML_XNODE_PARENT:
		g_value_take_object (value, gxml_xnode_get_parent (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_xnode_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlxNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_XNODE, GXmlxNode);
	switch (property_id) {
		case GXML_XNODE_NAMESPACE_DEFINITIONS:
		gxml_xnode_set_namespace_definitions (self, g_value_get_object (value));
		break;
		case GXML_XNODE_NAMESPACE_URI:
		gxml_xnode_set_namespace_uri (self, g_value_get_string (value));
		break;
		case GXML_XNODE_NAMESPACE_PREFIX:
		gxml_xnode_set_namespace_prefix (self, g_value_get_string (value));
		break;
		case GXML_XNODE_LOCAL_NAME:
		gxml_xnode_set_local_name (self, g_value_get_string (value));
		break;
		case GXML_XNODE_NODE_NAME:
		gxml_xnode_set_node_name (self, g_value_get_string (value));
		break;
		case GXML_XNODE_NODE_VALUE:
		gxml_xnode_set_node_value (self, g_value_get_string (value));
		break;
		case GXML_XNODE_NODE_TYPE:
		gxml_xnode_set_node_type (self, g_value_get_enum (value));
		break;
		case GXML_XNODE_PARENT_NODE:
		gxml_xnode_set_parent_node (self, g_value_get_object (value));
		break;
		case GXML_XNODE_CHILD_NODES:
		gxml_xnode_set_child_nodes (self, g_value_get_object (value));
		break;
		case GXML_XNODE_FIRST_CHILD:
		gxml_xnode_set_first_child (self, g_value_get_object (value));
		break;
		case GXML_XNODE_LAST_CHILD:
		gxml_xnode_set_last_child (self, g_value_get_object (value));
		break;
		case GXML_XNODE_PREVIOUS_SIBLING:
		gxml_xnode_set_previous_sibling (self, g_value_get_object (value));
		break;
		case GXML_XNODE_NEXT_SIBLING:
		gxml_xnode_set_next_sibling (self, g_value_get_object (value));
		break;
		case GXML_XNODE_ATTRIBUTES:
		gxml_xnode_set_attributes (self, g_value_get_object (value));
		break;
		case GXML_XNODE_OWNER_DOCUMENT:
		gxml_xnode_set_owner_document (self, g_value_get_object (value));
		break;
		case GXML_XNODE_VALUE:
		gxml_xnode_set_value (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



